==> libksysguard_5.12.8.orig.tar.xz: libksysguard-5.12.8/lsofui/LsofSearchWidget.cpp <==
/*
    KSysGuard, the KDE System Guard

	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
	Copyright (c) 2007 John Tapsell <tapsell@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.


*/

#include <KLocalizedString>
#include <KConfigGroup>
#include <QDialogButtonBox>
#include <QPushButton>
#include <QVBoxLayout>


#include "ui_LsofSearchWidget.h"

LsofSearchWidget::LsofSearchWidget(QWidget* parent, int pid )
	: QDialog( parent )
{
	setObjectName( "Renice Dialog" );
	setModal( true );
	setWindowTitle( i18n("Renice Process") );
	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
	QWidget *mainWidget = new QWidget(this);
	QVBoxLayout *mainLayout = new QVBoxLayout;
	setLayout(mainLayout);
	mainLayout->addWidget(mainWidget);
	connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
	QWidget *widget = new QWidget(this);
	mainLayout->addWidget(widget);
        mainLayout->addWidget(buttonBox);
	ui = new Ui_LsofSearchWidget();
	ui->setupUi(widget);
	ui->klsofwidget->setPid(pid);
	ktreewidgetsearchline
}

==> libksysguard-5.19.2.tar.xz: libksysguard-5.19.2/lsofui/LsofSearchWidget.cpp <==
/*
    KSysGuard, the KDE System Guard

	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
	Copyright (c) 2007 John Tapsell <tapsell@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.


*/

#include <KLocalizedString>
#include <KConfigGroup>
#include <QDialogButtonBox>
#include <QPushButton>
#include <QVBoxLayout>


#include "ui_LsofSearchWidget.h"

LsofSearchWidget::LsofSearchWidget(QWidget* parent, int pid )
	: QDialog( parent )
{
	setObjectName( "Renice Dialog" );
	setModal( true );
	setWindowTitle( i18n("Renice Process") );
	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
	QWidget *mainWidget = new QWidget(this);
        QVBoxLayout *mainLayout = new QVBoxLayout(this);
	mainLayout->addWidget(mainWidget);
	connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
	QWidget *widget = new QWidget(this);
	mainLayout->addWidget(widget);
        mainLayout->addWidget(buttonBox);
	ui = new Ui_LsofSearchWidget();
	ui->setupUi(widget);
	ui->klsofwidget->setPid(pid);
	ktreewidgetsearchline
}


LsofSearchWidget::~LsofSearchWidget()
{
    delete ui;
}
